==> jersey-multipart-1.0.3.1-sources.jar: com/sun/jersey/multipart/file/MediaTypePredictor.java <==
/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://jersey.dev.java.net/CDDL+GPL.html
 * or jersey/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at jersey/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.jersey.multipart.file;

import java.io.File;
import javax.ws.rs.core.MediaType;

/**
 * An interface which allows developers implement their own media type
 * predictor.
 *
 * @author imran@smartitengineering.com
 * @author Paul.Sandoz@Sun.Com
 */
public interface MediaTypePredictor {

    /**
     * Get the media type from a file name.
     *
     * @param file The file from which to get the {@link MediaType}
     * @return The {@link MediaType} for the give file; <code>null</code> - if file
     *          is null; "application/octet-stream" if extension not recognized.
     * @see CommonMediaType#getMediaTypeFromFileName(java.lang.String)
     */
    public MediaType getMediaTypeFromFile(final File file);

    /**
     * Get the media type from a file name. If the file
     * name extension is not recognised it will return {@link MediaType} for
     * "*\/*", it will also return the same if the file is <code>null</code>.
     *
     * @param fileName  The file name from which to get the {@link MediaType}
     * @return The {@link MediaType} for the give file; <code>null</code> - if file
     *          is null; "application/octet-stream" if extension not recognized.
     */
    public MediaType getMediaTypeFromFileName(String fileName);
}

==> jersey-multipart-1.1.5.1-sources.jar: com/sun/jersey/multipart/file/MediaTypePredictor.java <==
/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://jersey.dev.java.net/CDDL+GPL.html
 * or jersey/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at jersey/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.jersey.multipart.file;

import java.io.File;
import javax.ws.rs.core.MediaType;
import com.sun.jersey.multipart.file.DefaultMediaTypePredictor.CommonMediaTypes;

/**
 * An interface which allows developers implement their own media type
 * predictor.
 *
 * @author imran@smartitengineering.com
 * @author Paul.Sandoz@Sun.Com
 */
public interface MediaTypePredictor {

    /**
     * Get the media type from a file name.
     *
     * @param file The file from which to get the {@link MediaType}
     * @return The {@link MediaType} for the give file; <code>null</code> - if file
     *          is null; "application/octet-stream" if extension not recognized.
     * @see CommonMediaTypes#getMediaTypeFromFileName(java.lang.String)
     */
    public MediaType getMediaTypeFromFile(final File file);

    /**
     * Get the media type from a file name. If the file
     * name extension is not recognised it will return {@link MediaType} for
     * "*\/*", it will also return the same if the file is <code>null</code>.
     *
     * @param fileName  The file name from which to get the {@link MediaType}
     * @return The {@link MediaType} for the give file; <code>null</code> - if file
     *          is null; "application/octet-stream" if extension not recognized.
     */
    public MediaType getMediaTypeFromFileName(String fileName);
}
